from distutils.core import setup
setup( 
 name = 'tieu', 
 version = '1.0.1', 
 py_modules = ['tieu'],
 author = 'hfpython',
 author_email = 'hfpython@headfirstlabs.com',
 url = 'http://www.headfirstlabs.com',
 description = 'A simple printer of nested lists',
     )
